getACISData: Download Data Served through ACIS?

Description Usage Arguments Value Author(s)

Description

GETUSOMEDATA

Usage

1
2
getACISData(sid, start_date, end_date,
  vars = "mint,maxt,avgt,pcpn,snow,snwd,obst")

Arguments

sid

Parameter of class character. The (GHCND) site ID of the site data should be downloaded for.

start_date

Parameter of class character. The year-month-day (e.g. "2017-01-02") of the last date to get data for.

end_date

Parameter of class character. The year-month-day (e.g. "2017-01-02") of the last date to get data for.

vars

Optional. A string of element codes, separated by commas only. Defaults to "mint,maxt,avgt,pcpn,snow,snwd,obst"

Value

Writes results file to the specified directory.

Author(s)

Cody Flagg cflagg@battelleecology.org


rhlee12/metget documentation built on June 7, 2019, 10:41 p.m.