getData: Pull data for a site found with metScanR

Description Usage Arguments Value Author(s) See Also Examples

Description

This function takes an input of the site metadata from a metScanR search, as well as start and end dates to download data for, and downloads

Usage

1
getData(site_meta, start_date, end_date, temp_agg, token = NA)

Arguments

site_meta

a metScanR list element.

start_date

A YYYY-MM-DD hh:mm:ss formated start time

end_date

A YYYY-MM-DD hh:mm:ss formated end time

temp_agg

The temporal agregation of the data (or period of reporting). Can be one of "monthly","daily", "hourly", or "subhourly".

token

Optional, but required for Mesonet stations. See: https://developers.synopticdata.com/mesonet/ for more information.

Value

Data frame data for the input site found with metScanR, if available.

Author(s)

Robert Lee rlee@battelleecology.org
Josh Roberti

See Also

Currently none

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
## Not run: 
# Get Data for one SCAN site near CPER
cper_sites=metScanR::getNearby(siteID="NEON:CPER", radius = 30)
uscrn_out=metDownloadR::getData(site_meta = cper_sites$USW00094074,
                              start_date = "2018-10-01",
                             end_date = "2018-10-31", 
                             temp_agg="monthly")
# Get all october 2018 data from sites within a 5 km radius of CPER
out=lapply(
metScanR::getNearby(siteID="NEON:CPER", radius = 30),
metDownloadR::getData,
start_date = "2018-10-01",
end_date = "2018-10-31", 
temp_agg="daily")

## End(Not run)

rhlee12/metget documentation built on June 7, 2019, 10:41 p.m.