Description Usage Arguments Value Author(s) Examples
Provide a valid mesonet ID for a site in the mesonetwork; your personal mesonetwork data token, and requested begin and end times in POSIX format, and a data frame will be returned to the global environment.
1 | getMesonetData(token, mesoId, timeBgn, timeEnd)
|
token |
Personalized Mesonetwork token. This is needed to download data; see https://developers.synopticdata.com/mesonet/v2/auth/ for more information. |
mesoId |
Mesonet ID for site of interest |
timeBgn |
A YYYY-MM-DD hh:mm:ss formated start time, in UTC. |
timeEnd |
A YYYY-MM-DD hh:mm:ss formated end time, in UTC. |
Data frame of mesonet data
Josh Roberti jroberti@battelleecology.org
1 2 3 4 5 6 7 8 9 10 11 12 | ## Not run:
token="16088448e1b149509e45e401196106f0"
mesoId="TR951"
timeBgn="2019-01-01 00:00:00"
timeEnd="2019-02-01 00:00:00"
getMesonetData(timeBgn = timeBgn,
timeEnd = timeEnd,
mesoId=mesoId,
token=token)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.