getUSCRNData: Pull data from meterologic stations in the USCRN network

Description Usage Arguments Value Author(s) See Also Examples

Description

Provide a valid GHCND or WBAN ID for a site in the USCRN, the desired timescale of measurements, and requested begin and end times in POSIX format, and a data frame will be returned to the global environment.

Usage

1
getUSCRNData(temp_agg, sid, start_date, end_date)

Arguments

temp_agg

The time scale of measurements to return. Enter 'monthly', 'daily', 'hourly', or 'subhourly'.

sid

The WBAN ID of a valid USCRN site.

start_date

YYYY-MM-DD hh:mm:ss formated start time, in UTC.

end_date

A YYYY-MM-DD hh:mm:ss formated end time, in UTC.

Value

Data frame of USCRN data.

Author(s)

Robert Lee rlee@battelleecology.org

See Also

Currently none

Examples

1
2
3
4
5
6
7
8
9
## Not run: 
temp_agg <- "subhourly"
sid <- "USW00003047"
start_date <- as.POSIXct("2014-04-01 00:00:01", format="%Y-%m-%d %H:%M:%S", tz="UTC")
end_date <- as.POSIXct("2015-02-01 00:00:00", format = "%Y-%m-%d %H:%M:%S", tz="UTC")

grabUSCRN(temp_agg = temp_agg, TimeBgn = TimeBgn, TimeEnd = TimeEnd, sid = sid)

## End(Not run)

rhlee12/metget documentation built on June 7, 2019, 10:41 p.m.