resTracking: Mapping of Temporal Resolution of Data by Platform and ID

Description Usage Format

Description

A data frame of ID types, platforms, R packages to access sensor data, and the possible temporal resolutions of data served through each platform/ID type. Used to properly request data with getData.

Usage

1

Format

Data frame


rhlee12/metget documentation built on June 7, 2019, 10:41 p.m.