Description Usage Arguments Value Author(s)
GETUSOMEDATA
1 2 | getACISData(sid, start_date, end_date,
vars = "mint,maxt,avgt,pcpn,snow,snwd,obst")
|
sid |
Parameter of class character. The (GHCND) site ID of the site data should be downloaded for. |
start_date |
Parameter of class character. The year-month-day (e.g. "2017-01-02") of the last date to get data for. |
end_date |
Parameter of class character. The year-month-day (e.g. "2017-01-02") of the last date to get data for. |
vars |
Optional. A string of element codes, separated by commas only. Defaults to "mint,maxt,avgt,pcpn,snow,snwd,obst" |
Writes results file to the specified directory.
Cody Flagg cflagg@battelleecology.org
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.