Description Usage Arguments Value Author(s) See Also Examples
Provide a valid GHCND or WBAN ID for a site in the USCRN, the desired timescale of measurements, and requested begin and end times in POSIX format, and a data frame will be returned to the global environment.
1 | getUSCRNData(temp_agg, sid, start_date, end_date)
|
temp_agg |
The time scale of measurements to return. Enter 'monthly', 'daily', 'hourly', or 'subhourly'. |
sid |
The WBAN ID of a valid USCRN site. |
start_date |
YYYY-MM-DD hh:mm:ss formated start time, in UTC. |
end_date |
A YYYY-MM-DD hh:mm:ss formated end time, in UTC. |
Data frame of USCRN data.
Robert Lee rlee@battelleecology.org
Currently none
1 2 3 4 5 6 7 8 9 | ## Not run:
temp_agg <- "subhourly"
sid <- "USW00003047"
start_date <- as.POSIXct("2014-04-01 00:00:01", format="%Y-%m-%d %H:%M:%S", tz="UTC")
end_date <- as.POSIXct("2015-02-01 00:00:00", format = "%Y-%m-%d %H:%M:%S", tz="UTC")
grabUSCRN(temp_agg = temp_agg, TimeBgn = TimeBgn, TimeEnd = TimeEnd, sid = sid)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.